Conclusion
==========

As you can imagine, having the ability to parse maps, icons, and the codebase at
the same time, with a single library, for use in scripting, can be very
powerful, and enable automation of things that would be challenging to do
manually, or impossible to do with existing tools.
